<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter;

use OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\IdentityTranslator;
use OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\MessageSelector;
use OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\TranslatorInterface as LegacyTranslatorInterface;
use OctolizeShippingAustraliaPostVendor\Symfony\Contracts\Translation\TranslatorInterface;
// Help opcache.preload discover always-needed symbols
\class_exists(\OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\IntlFormatter::class);
/**
 * @author Abdellatif Ait boudad <a.aitboudad@gmail.com>
 */
class MessageFormatter implements \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\MessageFormatterInterface, \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\IntlFormatterInterface, \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\ChoiceMessageFormatterInterface
{
    private $translator;
    private $intlFormatter;
    /**
     * @param TranslatorInterface|null $translator An identity translator to use as selector for pluralization
     */
    public function __construct($translator = null, \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\IntlFormatterInterface $intlFormatter = null)
    {
        if ($translator instanceof \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\MessageSelector) {
            $translator = new \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\IdentityTranslator($translator);
        } elseif (null !== $translator && !$translator instanceof \OctolizeShippingAustraliaPostVendor\Symfony\Contracts\Translation\TranslatorInterface && !$translator instanceof \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\TranslatorInterface) {
            throw new \TypeError(\sprintf('Argument 1 passed to "%s()" must be an instance of "%s", "%s" given.', __METHOD__, \OctolizeShippingAustraliaPostVendor\Symfony\Contracts\Translation\TranslatorInterface::class, \is_object($translator) ? \get_class($translator) : \gettype($translator)));
        }
        $this->translator = $translator ?? new \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\IdentityTranslator();
        $this->intlFormatter = $intlFormatter ?? new \OctolizeShippingAustraliaPostVendor\Symfony\Component\Translation\Formatter\IntlFormatter();
    }
    /**
     * {@inheritdoc}
     */
    public function format($message, $locale, array $parameters = [])
    {
        if ($this->translator instanceof \OctolizeShippingAustraliaPostVendor\Symfony\Contracts\Translation\TranslatorInterface) {
            return $this->translator->trans($message, $parameters, null, $locale);
        }
        return \strtr($message, $parameters);
    }
    /**
     * {@inheritdoc}
     */
    public function formatIntl(string $message, string $locale, array $parameters = []) : string
    {
        return $this->intlFormatter->formatIntl($message, $locale, $parameters);
    }
    /**
     * {@inheritdoc}
     *
     * @deprecated since Symfony 4.2, use format() with a %count% parameter instead
     */
    public function choiceFormat($message, $number, $locale, array $parameters = [])
    {
        @\trigger_error(\sprintf('The "%s()" method is deprecated since Symfony 4.2, use the format() one instead with a %%count%% parameter.', __METHOD__), \E_USER_DEPRECATED);
        $parameters = ['%count%' => $number] + $parameters;
        if ($this->translator instanceof \OctolizeShippingAustraliaPostVendor\Symfony\Contracts\Translation\TranslatorInterface) {
            return $this->format($message, $locale, $parameters);
        }
        return $this->format($this->translator->transChoice($message, $number, [], null, $locale), $locale, $parameters);
    }
}
